==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/modules/admin/messages/ru/space.php <==
<?php

return [
    '<strong>Manage</strong> Spaces' => '<strong>Управление сообществами</strong>',
    'Add new space' => 'Добавить новое сообщество',
    'By using user roles, you can create different permission groups within a Space. These can also be individualized by authorized users for each and every Space and are only relevant for that specific Space.' => 'Используя пользовательские роли, вы можете создавать различные группы разрешений в Сообществе. Они также могут быть индивидуализированы авторизованными пользователями для каждого Сообщества и относятся только к этому конкретному Сообществу.',
    'Change owner' => 'Сменить владельца сообщества',
    'Default Content Visiblity' => 'Видимость контента по умолчанию',
    'Default Join Policy' => 'Доступ по умолчанию',
    'Default Space Permissions' => 'Разрешения сообщества по умолчанию',
    'Default Space(s)' => 'Сообщество(а) по умолчанию',
    'Default Visibility' => 'Видимость по умолчанию',
    'Default space' => 'Cообщество по умолчанию',
    'Here you can define your default settings for new spaces. These settings can be overwritten for each individual space.' => 'Здесь Вы можете задать настройки по умолчанию для новых сообществ. Эти параметры могут быть изменены для каждого отдельного сообщества.',
    'Invalid space' => 'Неверное сообщество',
    'Manage members' => 'Управление пользователями',
    'Manage modules' => 'Управление модулями',
    'Open space' => 'Открыть сообщество',
    'Overview' => 'Список сообществ',
    'Permissions' => 'Доступ',
    'Search by name, description, id or owner.' => 'Поиск по названию, описанию, id или владельцу сообщества',
    'Settings' => 'Настройки',
    'Space Settings' => 'Настройки сообществ',
    'These options allow you to set the default permissions for all Spaces. Authorized users are able individualize these for each Space. Further entries are added with the installation of new modules.' => 'Эти опции позволяют вам установить разрешения по умолчанию для всех Сообществ. Авторизованные пользователи могут индивидуализировать их для каждого Сообщества. Дальнейшие записи добавляются при установке новых модулей.',
    'This overview contains a list of each space with actions to view, edit and delete spaces.' => 'Содержит список сообществ с возможностью просмотра, редактирования и удаления.',
    'Update Space memberships also for existing members.' => 'Обновление членств в Сообществах также для существующих членов.',
    'Default "Hide About Page"' => '',
    'Default "Hide Activity Sidebar Widget"' => '',
    'Default "Hide Followers"' => '',
    'Default "Hide Members"' => '',
    'Default Homepage' => '',
    'Default Homepage (Non-members)' => '',
];

==> humhub-1.17.0-beta.2.tar.gz: humhub-1.17.0-beta.2/protected/humhub/modules/admin/messages/ru/space.php <==
<?php

return [
    '<strong>Manage</strong> Spaces' => '<strong>Управление сообществами</strong>',
    'Add new space' => 'Добавить новое сообщество',
    'By using user roles, you can create different permission groups within a Space. These can also be individualized by authorized users for each and every Space and are only relevant for that specific Space.' => 'Используя пользовательские роли, вы можете создавать различные группы разрешений в Сообществе. Они также могут быть индивидуализированы авторизованными пользователями для каждого Сообщества и относятся только к этому конкретному Сообществу.',
    'Change owner' => 'Сменить владельца сообщества',
    'Default "Hide About Page"' => 'По умолчанию «Скрыть страницу о странице»',
    'Default "Hide Activity Sidebar Widget"' => 'По умолчанию «Скрыть виджет боковой панели активности»',
    'Default "Hide Followers"' => 'По умолчанию «Скрыть подписчиков»',
    'Default "Hide Members"' => 'По умолчанию «Скрыть участников»',
    'Default Content Visiblity' => 'Видимость контента по умолчанию',
    'Default Homepage' => 'Домашняя страница по умолчанию',
    'Default Homepage (Non-members)' => 'Домашняя страница по умолчанию (не члены)',
    'Default Join Policy' => 'Доступ по умолчанию',
    'Default Space Permissions' => 'Разрешения сообщества по умолчанию',
    'Default Space(s)' => 'Сообщество(а) по умолчанию',
    'Default Visibility' => 'Видимость по умолчанию',
    'Default space' => 'Cообщество по умолчанию',
    'Here you can define your default settings for new spaces. These settings can be overwritten for each individual space.' => 'Здесь Вы можете задать настройки по умолчанию для новых сообществ. Эти параметры могут быть изменены для каждого отдельного сообщества.',
    'Invalid space' => 'Неверное сообщество',
    'Manage members' => 'Управление пользователями',
    'Manage modules' => 'Управление модулями',
    'Open space' => 'Открыть сообщество',
    'Overview' => 'Список сообществ',
    'Permissions' => 'Доступ',
    'Search by name, description, id or owner.' => 'Поиск по названию, описанию, id или владельцу сообщества',
    'Settings' => 'Настройки',
    'Space Settings' => 'Настройки сообществ',
    'These options allow you to set the default permissions for all Spaces. Authorized users are able individualize these for each Space. Further entries are added with the installation of new modules.' => 'Эти опции позволяют вам установить разрешения по умолчанию для всех Сообществ. Авторизованные пользователи могут индивидуализировать их для каждого Сообщества. Дальнейшие записи добавляются при установке новых модулей.',
    'This overview contains a list of each space with actions to view, edit and delete spaces.' => 'Содержит список сообществ с возможностью просмотра, редактирования и удаления.',
    'Update Space memberships also for existing members.' => 'Обновление членств в Сообществах также для существующих членов.',
    'All existing Space Topics will be converted to Global Topics.' => '',
    'Allow individual topics in Spaces' => '',
    'Convert' => '',
    'Convert Space Topics' => '',
    'Default Stream Sort' => '',
];
